<?php

/**
 * The control file of kuntaichart module
 *
 * @copyright   上海锟钛软件科技有限公司 2022
 * @license     ZPL(http://zpl.pub/page/zplv12.html) or MIT
 * @author      kuntai<kuntai@kuntaisoft.cn>
 * @link        http://www.kuntaisoft.cn
 */

class kuntaichart extends control {

	/**
	 * Construct function.
	 * 
	 * @access public
	 * @return void
	 */
	public function __construct() {
		parent::__construct();
		$this->app->loadClass('date');
	}

	public function commonWebParam(& $period) {
		if (!$period) {
			$period = date('today');
		}

		$currentMonth = date('Y-m') . '-01';
		if (is_numeric($period) && 6 == strlen($period)) {
			$currentMonth	 = $period . '01';
			$currentMonth	 = date('Y-m', strtotime($currentMonth)) . '-01';
		}
		if (is_numeric($period) && strlen($period) == 8) {
			$this->view->currentDate = date('Y-m-d', strtotime($period));
		} else
			$this->view->currentDate = date('Y-m-d');

		$this->view->lastMonth	 = date('Ym', strtotime("$currentMonth -1 month"));
		$this->view->nextMonth	 = date('Ym', strtotime("$currentMonth +1 month"));
		$this->view->thisMonth	 = date('Ym');
		$this->view->period		 = $period;

		$this->view->methodName		 = $this->app->getMethodName();
		$this->view->yearList		 = kuntai::getYearList();
		$this->view->monthList		 = kuntai::getMonthListOneYear();
		$this->view->currentYear	 = date('Y', strtotime("$currentMonth"));
		$this->view->currentMonth	 = date('m', strtotime("$currentMonth"));
	}

	/**
	 * view a line for app of app.
	 * 
	 * @param  int $userhost   the int userhost userhost
	 * @param  string $period   period for app
	 * @access public
	 * @return void
	 */
	public function chartcurve($period = 'all') {
		//period treat
		$this->commonWebParam($period);
		extract(kuntai::getBeginEndTime($period));

		$this->view->charData = null;
		if ($this->kuntaichart->ktGetPoints($begin, $end, 'chartcurve')) {
			$this->view->chartData = & $this->kuntaichart->chartData; //get ref
		}
		$this->view->baseLinkVars	 = "period=$period";

		$thisLang				 = & $this->lang->kuntaichart;
		$this->view->title		 = $thisLang->common . $this->lang->colon . $thisLang->chartcurve;
		$this->view->position[]	 = html::a($this->createLink($this->moduleName, 'index'), $thisLang->common);
		$this->view->position[]	 = $thisLang->chartcurve;
		$this->display();
	}

	/**
	 * Browse chartlist and dailyItems.
	 * 
	 * @param  string $period 
	 * @param  string $orderBy 
	 * @param  int    $recTotal 
	 * @param  int    $recPerPage 
	 * @param  int    $pageID 
	 * @access public
	 * @return void
	 */
	public function chartlist( $period = 'all', $orderBy = 'start', $recTotal = 0, $recPerPage = 10, $pageID = 1) {
		//period treat
		$this->commonWebParam($period);
		extract(kuntai::getBeginEndTime($period));
	
		/* Set the pager. */
		$this->app->loadClass('pager', $static	 = true);
		$pager	 = pager::init($recTotal, $recPerPage, $pageID);

		/* Append id for secend sort. */
		$sort = kuntai::appendOrder($orderBy);

		$this->view->myItems		 = $this->kuntaichart->ktGetList($begin, $end, $pager, $sort);
		$this->view->baseLinkVars	 = "period=$period";
		$this->view->pager			 = $pager;
		$this->view->orderBy		 = $orderBy;

		$thisLang				 = & $this->lang->kuntaichart;
		$this->view->title		 = $thisLang->common . $this->lang->colon . $thisLang->chartlist;
		$this->view->position[]	 = html::a($this->createLink($this->moduleName, 'index'), $thisLang->common);
		$this->view->position[]	 = $thisLang->chartlist;

		$this->display();
	}

	/**
	 * Browse index and myItems.
	 * 
	 * @param  int    $param 
	 * @param  string $type 
	 * @param  string $orderBy 
	 * @param  int    $recTotal 
	 * @param  int    $recPerPage 
	 * @param  int    $pageID 
	 * @access public
	 * @return void
	 */
	public function chartindex( ) {
		$this->view->title	= $this->lang->kuntaichart->common . $this->lang->colon . $this->lang->kuntaichart->index;
		$this->view->position[]	 = $this->lang->kuntaichart->common;
		$this->display();
	}

	/**
	 * view a app.
	 * 
	 * @param  int $id   the int id
	 * @access public
	 * @return void
	 */
	public function chartview($id) {
		if (!$id) {
			die(js::error("Input app ID wrong, must a right number!"));
		}

		$this->view->myItem = $this->kuntaichart->ktGetById($id);
		if (!$id) {
			die(js::error("Can not find the app by this id = " . $id));
		}
		$thisLang				 = & $this->lang->kuntaichart;
		$this->view->title		 = $thisLang->common . $this->lang->colon . $thisLang->view;
		$this->view->position[]	 = html::a($this->createLink($this->moduleName, 'index'), $thisLang->common);
		$this->view->position[]	 = $thisLang->view;

		$this->display();
	}

}
